var TermBlasterOptions = {
  /**
   * Load values into window
   */
  onLoad: function() {
    this.txtDatabaseLocation = document.getElementById("txtDatabaseLocation");
    this.txtQuickListLocation = document.getElementById("txtQuickListLocation");
    this.rgDestination = document.getElementById("rgDestination");

    this.populate(this.txtDatabaseLocation);
    this.populate(this.txtQuickListLocation);

    var prefs = Components.classes["@mozilla.org/preferences-service;1"].
                    getService(Components.interfaces.nsIPrefBranch);
    if (prefs.getPrefType("extensions.termblaster.opened.database") != prefs.PREF_STRING
     || prefs.getPrefType("extensions.termblaster.opened.quicklist") != prefs.PREF_STRING
     || prefs.getPrefType("extensions.termblaster.destination") != prefs.PREF_INT) {
     prefs.clearUserPref('extensions.termblaster.');
   }

   this.displayPrefs();
  },
  
  displayPrefs: function() {
    try {
      var prefs = Components.classes["@mozilla.org/preferences-service;1"].
                    getService(Components.interfaces.nsIPrefBranch);
      this.txtDatabaseLocation.value = prefs.getCharPref("extensions.termblaster.opened.database");
      this.txtQuickListLocation.value = prefs.getCharPref("extensions.termblaster.opened.quicklist");
      this.rgDestination.selectedIndex = prefs.getIntPref("extensions.termblaster.destination");
    } catch (e) {
      alert("termBlaster could not load preferences: " + e.message);
    }
  },

  /**
   * Open a browse dialog
   *
   * @param txtField Textfield where the selected file will be displayed
   */
  btnBrowseCommand: function(txtField) {
    var nsIFilePicker = Components.interfaces.nsIFilePicker;
    var fp = Components.classes["@mozilla.org/filepicker;1"].createInstance(nsIFilePicker);

    fp.init(window, "Select a File", nsIFilePicker.modeOpen);
    fp.appendFilter("termBlaster Files", "*.tbd; *.tbq");

    if (fp.show() == nsIFilePicker.returnOK && fp.fileURL.spec && fp.fileURL.spec.length > 0) {
      var thefile = fp.file;
      txtField.value = fp.fileURL.spec;
    }
  },

  /**
   * Commit changes
   */
  btnOkCommand: function() {
    var prefs = Components.classes["@mozilla.org/preferences-service;1"].
                    getService(Components.interfaces.nsIPrefBranch);

    prefs.setCharPref("extensions.termblaster.opened.database", this.txtDatabaseLocation.value);
    prefs.setCharPref("extensions.termblaster.opened.quicklist", this.txtQuickListLocation.value);
    prefs.setIntPref("extensions.termblaster.destination", this.rgDestination.selectedIndex);

    Components.classes["@mozilla.org/observer-service;1"]
       .getService(Components.interfaces.nsIObserverService)
       .notifyObservers(null, "TermBlasterOptions_btnOkCommand", null);
  },

  /**
   * Reset changes
   */
  resetFields: function() {
    this.txtDatabaseLocation.value = 'chrome://termblaster/content/data/Services.tbd';
    this.txtQuickListLocation.value = 'chrome://termblaster/content/data/QuickList.tbq';
    this.rgDestination.selectedIndex = '1';
  },

  /**
   * Dynamically generate files list
   *
   * @param menulist Menulist where the file list should be displayed
   */
  populate: function(menulist) {
    const id = "termblaster@forizon.com";
    var ext = Components.classes["@mozilla.org/extensions/manager;1"]
                  .getService(Components.interfaces.nsIExtensionManager)
                  .getInstallLocation(id)
                  .getItemLocation(id);
    var ios = Components.classes["@mozilla.org/network/io-service;1"]
                  .getService(Components.interfaces.nsIIOService);
    var fileHandler = ios.getProtocolHandler("file")
                  .QueryInterface(Components.interfaces.nsIFileProtocolHandler);

    ext.append("content");
    ext.append("data");

    var entries = ext.directoryEntries;
    var basename;
    while(entries.hasMoreElements())
    {
      var entry = entries.getNext();
      entry.QueryInterface(Components.interfaces.nsIFile);
      basename = fileHandler.getURLSpecFromFile(entry).replace(/.*\//, "");
      if (basename != '') {
        menulist.appendItem('chrome://termblaster/content/data/' + basename);
      }
    }

/*
    var header = menulist.appendItem('Previously Opened Files:');
    header.setAttribute("disabled", "true");
    var seperator = document.createElementNS("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul", "menuseparator");
    header.parentNode.appendChild(seperator);
*/
  }
};
